\name{read.dat}
\alias{read.dat}
\title{
  Read and recode a headerless file
}
\description{
  This allows one to read a space-delimited text file and provide variable names.
  Optionally, one may specify some variables as factors and/or re-code data
  values of 1, 2, ... to some other values
}
\usage{
read.dat(name, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{name}{name of the data file to read}
  \item{\dots}{names and recodings, as described below}
}
\details{
  The name and recoding information must be entered for every column in the data file,
  in order of appearance. Each entry can be in one of these forms:
  \describe{
    \item{"name"}{The variable is named \code{name} and stored as given in the file.}
    \item{name=0}{Same as above}
    \item{name=c(12,56,94)}{Creates a numeric variable.  A value of 1 is changed to 12, a value of 2 is changed to 56,
      and a value of 3 is changed to 94.}
    \item{name=""}{Creates a fqactor with levels 1, 2, 3, ...}
    \item{name=c("Oral","IV","Control")}{Creates a factor with the given levels corresponding to the codes 1, 2, 3 respectively.}
  }
}
\value{A data frame containing the variables specified.}
\author{
Russ Lenth
}
\note{
This was cobbled together to read data files provided with Oehlert's (2000 and 2010) textbook,
which follow a pretty rigid structure. The limitations of this function are similarly rigid.
For example, the files do not have a heading row; and so this function does not provided for that possibility.

When values are recoded to string values, those values are used as labels to create a factor variable.
Subsequently, \code{as.numeric()} will return the original codes.
}

\examples{
\dontrun{
pr12.7 = read.dat ("Problems/pr12-7.dat",
  days=c(1, 28, 56, 84), cheese="", r21=c("no","yes"), r50=c("no","yes"), freeAA=0)
}
}
\references{
Oehlert, Gary W. (2000), \emph{A First Course in Design and Analysis of Experiments},
New York: WH Freeman and Company. (Also copyright 2010 by Gary W. Oehlert, published 
under Creative Commons copyright, available at http://www.stat.umn.edu/~gary/Book.html
}
\keyword{ data }
